@@ -1,4 +1,4 @@
-'''
+"""
 File: __init__.py
 Project: tools
 Author: Jan Range
@@ -8,9 +8,10 @@ Last Modified: Tuesday June 22nd 2021 10:15:24 pm
 Modified By: Jan Range (<jan.range@simtech.uni-stuttgart.de>)
 -----
 Copyright (c) 2021 Institute of Biochemistry and Technical Biochemistry Stuttgart
-'''
+"""
 
-from pyenzyme.enzymeml.tools.enzymemlreader import EnzymeMLReader
 from pyenzyme.enzymeml.tools.enzymemlwriter import EnzymeMLWriter
-from pyenzyme.enzymeml.tools.unitparser  import UnitParser
+from pyenzyme.enzymeml.tools.unitparser import UnitParser
 from pyenzyme.enzymeml.tools.unitcreator import UnitCreator
+from pyenzyme.enzymeml.tools.templatereader import read_template
+from pyenzyme.enzymeml.tools.validator import EnzymeMLValidator
